using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Telerik.Web.UI;
using System.Web.Script.Serialization;
using System.Collections.Generic;

public partial class DynamicallyCreatedDockHandle : System.Web.UI.Page
{
    private List<DockState> OldDockStates
    {
        get
        {
            List<DockState> _oldDockStates = (List<DockState>)Session["OldDockStatesDynamicDocks"];
            if (Object.Equals(_oldDockStates, null))
            {
                _oldDockStates = new List<DockState>();
                Session["OldDockStatesDynamicDocks"] = _oldDockStates;
            }
            return _oldDockStates;
        }
        set
        {
            Session["OldDockStatesDynamicDocks"] = value;
        }
    }

    private List<DockState> CurrentDockStates
    {
        get
        {
            List<DockState> _currentDockStates = (List<DockState>)Session["CurrentDockStatesDynamicDocks"];
            if (Object.Equals(_currentDockStates, null))
            {
                _currentDockStates = new List<DockState>();
                Session["CurrentDockStatesDynamicDocks"] = _currentDockStates;
            }
            return _currentDockStates;
        }
        set
        {
            Session["CurrentDockStatesDynamicDocks"] = value;
        }
    }

    protected override void RaisePostBackEvent(IPostBackEventHandler sourceControl, string eventArgument)
    {
        base.RaisePostBackEvent(sourceControl, eventArgument);

        //As docks positions are authomatically saved when a postback occurs
        //if you want to save the current positions only at save button click
        //you need to reset to the old positions if save button has not beeb clicked
        if(sourceControl.GetType()==typeof(System.Web.UI.WebControls.Button))
        {    
            Button button = (Button)sourceControl;
            if (button.ID == "SaveButton" || button.ID == "RestoreButton")
            {
                return;
            }
        }
        SetPositions();
    }

    protected void Page_Init(object sender, EventArgs e)
    {  
        BuildThePage();
    }   

    private void BuildThePage()
    {  
        for (int i = 1; i <= 3; i++)
        {
            RadDock rd = new RadDock();
            rd.ID = "DockPhoto_" + i.ToString();
            rd.Title = "dock" + i.ToString();
            rd.OnClientInitialize = "SetHandleDock";
            Image img = new Image();
            img.CssClass = "thumbnail";
            img.ID = "thumbnail";
            img.ImageUrl = "~/Imgs/test" + i.ToString() + ".jpg";
            img.Width = Unit.Pixel(100);
            img.Height = Unit.Pixel(80);
            img.ToolTip = "Photo";
            rd.ContentContainer.Controls.Add(img);
            rd.DefaultCommands = Telerik.Web.UI.Dock.DefaultCommands.None;
            rd.Width = Unit.Pixel(120);
            rd.Height = Unit.Pixel(120);
            rd.EnableViewState = false;
            RadDockZoneHorizontal1.Controls.Add(rd);
        }
    }

    protected void RadDockLayout1_LoadDockLayout(object sender, DockLayoutEventArgs e)
    {
        //Populate the event args with the state information. The RadDockLayout control
        // will automatically move the docks according that information.
        foreach (DockState state in CurrentDockStates)
        {
            e.Positions[state.UniqueName] = state.DockZoneID;
            e.Indices[state.UniqueName] = state.Index;
        }
    }

    protected void RadDockLayout1_SaveDockLayout(object sender, DockLayoutEventArgs e)
    {
        //If the page is loaded for the first time
        //initialize the dock states
        if(!Page.IsPostBack)
        {
            OldDockStates = RadDockLayout1.GetRegisteredDocksState();
            CurrentDockStates = RadDockLayout1.GetRegisteredDocksState();
        }
    }

    protected void RestoreButton_Click(object sender, EventArgs e)
    {
        CurrentDockStates = OldDockStates;
        SetPositions();
    }
    protected void SaveButton_Click(object sender, EventArgs e)
    {
        OldDockStates = CurrentDockStates;
        //Saves the current positions only if save state button is clicked
        CurrentDockStates = RadDockLayout1.GetRegisteredDocksState();
        SetPositions();
    }

    private void SetPositions()
    {
        Dictionary<string, string> positions = new Dictionary<string, string>();
        Dictionary<string, int> indices = new Dictionary<string, int>();
        foreach (DockState state in CurrentDockStates)
        {
            positions[state.UniqueName] = state.DockZoneID;
            indices[state.UniqueName] = state.Index;
        }
        RadDockLayout1.SetRegisteredDockParents(positions, indices);
    }
}
